summaryrefslogtreecommitdiffstats
path: root/src/gui/ingen_gui_lv2.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/ingen_gui_lv2.cpp')
-rw-r--r--src/gui/ingen_gui_lv2.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/gui/ingen_gui_lv2.cpp b/src/gui/ingen_gui_lv2.cpp
index 937ecd38..d66405fb 100644
--- a/src/gui/ingen_gui_lv2.cpp
+++ b/src/gui/ingen_gui_lv2.cpp
@@ -19,15 +19,15 @@
#include "ingen/AtomWriter.hpp"
#include "ingen/World.hpp"
#include "ingen/client/ClientStore.hpp"
-#include "ingen/client/PatchModel.hpp"
+#include "ingen/client/GraphModel.hpp"
#include "ingen/client/SigClientInterface.hpp"
#include "ingen/runtime_paths.hpp"
#include "lv2/lv2plug.in/ns/extensions/ui/ui.h"
#include "App.hpp"
-#include "PatchBox.hpp"
+#include "GraphBox.hpp"
-#define INGEN_LV2_UI_URI "http://drobilla.net/ns/ingen#PatchUIGtk2"
+#define INGEN_LV2_UI_URI "http://drobilla.net/ns/ingen#GraphUIGtk2"
/** A sink that writes atoms to a port via the UI extension. */
struct IngenLV2AtomSink : public Ingen::AtomSink {
@@ -68,7 +68,7 @@ struct IngenLV2UI {
Ingen::World* world;
IngenLV2AtomSink* sink;
SharedPtr<Ingen::GUI::App> app;
- SharedPtr<Ingen::GUI::PatchBox> view;
+ SharedPtr<Ingen::GUI::GraphBox> view;
SharedPtr<Ingen::Interface> engine;
SharedPtr<Ingen::AtomReader> reader;
SharedPtr<Ingen::Client::SigClientInterface> client;
@@ -135,20 +135,20 @@ instantiate(const LV2UI_Descriptor* descriptor,
// Request plugins
ui->world->interface()->get(Raul::URI("ingen:plugins"));
// Create empty root patch model
Ingen::Resource::Properties props;
props.insert(std::make_pair(ui->app->uris().rdf_type,
- ui->app->uris().ingen_Patch));
+ ui->app->uris().ingen_Graph));
ui->app->store()->put(Ingen::GraphObject::root_uri(), props);
- // Create a PatchBox for the root and set as the UI widget
- SharedPtr<const Ingen::Client::PatchModel> root = PtrCast<const Ingen::Client::PatchModel>(
+ // Create a GraphBox for the root and set as the UI widget
+ SharedPtr<const Ingen::Client::GraphModel> root = PtrCast<const Ingen::Client::GraphModel>(
ui->app->store()->object(Raul::Path("/")));
- ui->view = Ingen::GUI::PatchBox::create(*ui->app, root);
+ ui->view = Ingen::GUI::GraphBox::create(*ui->app, root);
ui->view->unparent();
*widget = ui->view->gobj();
// Request the actual root patch
ui->world->interface()->get(Ingen::GraphObject::root_uri());
return ui;
@@ -135,20 +135,20 @@ instantiate(const LV2UI_Descriptor* descriptor,
// Request plugins
ui->world->interface()->get(Raul::URI("ingen:plugins"));
- // Create empty root patch model
+ // Create empty root graph model
Ingen::Resource::Properties props;
props.insert(std::make_pair(ui->app->uris().rdf_type,
@@ -135,20 +135,20 @@ instantiate(const LV2UI_Descriptor* descriptor,
ui->view->unparent();
*widget = ui->view->gobj();
- // Request the actual root patch
+ // Request the actual root graph
ui->world->interface()->get(Ingen::GraphObject::root_uri());
return ui;